@@ -1,13 +1,13 @@
 from typing import Sequence
 
-from exactly_lib.actors.util.executor_made_of_parts import parts
-from exactly_lib.actors.util.executor_made_of_parts.parts import ExecutableObjectParser
-from exactly_lib.test_case.actor import AtcOsProcessExecutor, Actor
+from exactly_lib.actors.util.actor_from_parts import parts
+from exactly_lib.actors.util.actor_from_parts.parts import ExecutableObjectParser
+from exactly_lib.test_case.actor import Actor
+from exactly_lib.test_case.os_services import OsServices
 from exactly_lib.test_case.phases.act import ActPhaseInstruction
 from exactly_lib.test_case.phases.common import SymbolUser
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPreSdsStep, \
     InstructionEnvironmentForPostSdsStep
-from exactly_lib.test_case.result import eh
 from exactly_lib.util.file_utils.std import StdFiles
 
 
@@ -31,13 +31,14 @@ class _Parser(ExecutableObjectParser):
 class _Executor(parts.Executor):
     def execute(self,
                 environment: InstructionEnvironmentForPostSdsStep,
-                std_files: StdFiles) -> eh.ExitCodeOrHardError:
-        return eh.new_eh_exit_code(0)
+                std_files: StdFiles,
+                ) -> int:
+        return 0
 
 
 class _ExecutorConstructor(parts.ExecutorConstructor[_ObjectToExecute]):
     def construct(self,
                   environment: InstructionEnvironmentForPreSdsStep,
-                  os_process_executor: AtcOsProcessExecutor,
+                  os_services: OsServices,
                   object_to_execute: _ObjectToExecute) -> parts.Executor:
         return _Executor()
