@@ -1,7 +1,9 @@
 from typing import Sequence
 
-from exactly_lib.actors import null, command_line
-from exactly_lib.actors.util.source_code_lines_utils import all_source_code_lines
+from exactly_lib.actors import null
+from exactly_lib.actors.program import actor
+from exactly_lib.actors.util.source_code_lines import all_source_code_lines
+from exactly_lib.definitions.entity import actors
 from exactly_lib.processing.act_phase import ActPhaseSetup
 from exactly_lib.processing.preprocessor import IdentityPreprocessor
 from exactly_lib.processing.test_case_handling_setup import TestCaseHandlingSetup
@@ -10,7 +12,8 @@ from exactly_lib.test_case.phases.act import ActPhaseInstruction
 
 
 def setup() -> TestCaseHandlingSetup:
-    return TestCaseHandlingSetup(ActPhaseSetup(TheActor()),
+    return TestCaseHandlingSetup(ActPhaseSetup(actors.COMMAND_LINE_ACTOR.singular_name,
+                                               TheActor()),
                                  IdentityPreprocessor())
 
 
@@ -20,4 +23,4 @@ class TheActor(Actor):
         if not source_code_lines:
             return null.actor().parse(instructions)
         else:
-            return command_line.actor().parse(instructions)
+            return actor.actor().parse(instructions)
