@@ -18,7 +18,6 @@ from exactly_lib.execution.partial_execution.result import PartialExeResult
 from exactly_lib.execution.result import ExecutionFailureStatus, PhaseStepFailure, PhaseStepFailureException
 from exactly_lib.test_case import phase_identifier
 from exactly_lib.test_case.actor import ActionToCheck, Actor
-from exactly_lib.test_case.os_services import new_default
 from exactly_lib.test_case.phases.cleanup import PreviousPhase
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPreSdsStep, \
     InstructionEnvironmentForPostSdsStep
@@ -26,6 +25,7 @@ from exactly_lib.test_case.phases.setup import SetupSettingsBuilder
 from exactly_lib.test_case.result.failure_details import FailureDetails
 from exactly_lib.test_case_file_structure.sandbox_directory_structure import SandboxDirectoryStructure, construct_at
 from exactly_lib.util.file_utils.misc_utils import resolved_path_name
+from exactly_lib.util.name_and_value import NameAndValue
 from exactly_lib.util.process_execution.execution_elements import ProcessExecutionSettings
 from exactly_lib.util.symbol_table import SymbolTable
 
@@ -60,7 +60,7 @@ def execute(exe_conf: Configuration,
     return executor.execute()
 
 
-def parse_atc_and_validate_symbols(actor: Actor,
+def parse_atc_and_validate_symbols(actor: NameAndValue[Actor],
                                    predefined_symbols: SymbolTable,
                                    test_case: TestCase,
                                    ) -> Tuple[ActionToCheck, SymbolTable]:
@@ -88,7 +88,7 @@ class _PartialExecutor:
         self._setup_settings_builder = conf.setup_settings_builder
         self._stdin_conf_from_setup = None
         self._source_setup = None
-        self._os_services = None
+        self._os_services = conf.exe_conf.os_services
         self._act_phase_executor = None
         self._action_to_check = None
         self._instruction_environment_pre_sds = None
@@ -209,7 +209,6 @@ class _PartialExecutor:
 
     def _setup_post_sds_environment(self):
         self._construct_and_set_sds()
-        self._os_services = new_default()
         self._set_cwd_to_act_dir()
         self.__post_sds_symbol_table = self.exe_conf.predefined_symbols.copy()
         self._phase_tmp_space_factory = phase_file_space.PhaseTmpFileSpaceFactory(
@@ -235,7 +234,8 @@ class _PartialExecutor:
         self._act_phase_executor = self._construct_act_phase_executor()
 
     def _act__parse_atc_executor(self):
-        self._action_to_check = ActionToCheckParser(self.conf_values.actor).parse(self._test_case.act_phase)
+        parser = ActionToCheckParser(self.conf_values.actor)
+        self._action_to_check = parser.parse(self._test_case.act_phase)
 
     def _act__validate_pre_sds(self):
         failure_con = PhaseStepFailureResultConstructor(phase_step.ACT__VALIDATE_PRE_SDS)
@@ -316,7 +316,7 @@ class _PartialExecutor:
                 self._phase_tmp_space_factory.for_phase__main(phase_identifier.ACT),
                 self.__post_sds_symbol_table,
             ),
-            self.exe_conf.atc_os_process_executor,
+            self._os_services,
             self._stdin_conf_from_setup,
             self.exe_conf.exe_atc_and_skip_assertions,
         )
