@@ -2,7 +2,7 @@ from abc import ABC, abstractmethod
 from typing import TypeVar, Generic, ContextManager
 
 from exactly_lib.type_system.logic.program.program import Program
-from exactly_lib.util.process_execution.process_executor import ProcessExecutionFile
+from exactly_lib.util.file_utils.std import ProcessExecutionFile
 
 MODEL = TypeVar('MODEL')
 
