@@ -10,7 +10,7 @@ SYSTEM_PROGRAM_TOKEN = program.SYSTEM_PROGRAM_TOKEN
 
 SYMBOL_REF_PROGRAM_TOKEN = instruction_names.SYMBOL_REF_PROGRAM_INSTRUCTION_NAME
 
-REL_OPTION_ARG_CONF = path_relativities.ALL_REL_OPTIONS_CONFIG
+EXE_FILE_REL_OPTION_ARG_CONF = path_relativities.ALL_REL_OPTIONS_ARG_CONFIG
 
 PYTHON_EXECUTABLE_OPTION_NAME = argument.OptionName(long_name='python')
 PYTHON_EXECUTABLE_OPTION_STRING = long_option_syntax(PYTHON_EXECUTABLE_OPTION_NAME.long)
