@@ -1,9 +1,9 @@
 import subprocess
 from contextlib import contextmanager
 from pathlib import Path
-from typing import ContextManager
+from typing import ContextManager, IO
 
-from exactly_lib.util.process_execution.process_executor import ProcessExecutionFile
+from exactly_lib.util.file_utils.std import ProcessExecutionFile
 
 
 @contextmanager
@@ -15,3 +15,8 @@ def dev_null() -> ContextManager[ProcessExecutionFile]:
 def open_file(path: Path, mode: str) -> ContextManager[ProcessExecutionFile]:
     with path.open(mode) as f:
         yield f
+
+
+@contextmanager
+def opened_file(f: IO) -> ContextManager[ProcessExecutionFile]:
+    yield f
